==> tecfy_basic_package-0.1.35.tar.gz: lib/views/components/button_icon_text.dart <==
part of tecfy_basic_package;

class AppButtonIconText extends StatefulWidget {
  final String label;
  final Widget icon;
  final double height;
  final Color color;
  final bool isFullRow;
  final Future Function() onPressed;
  AppButtonIconText(
      {this.label,
      this.icon,
      this.onPressed,
      this.color,
      this.height,
      this.isFullRow = false});
  @override
  _AppButtonIconTextState createState() => _AppButtonIconTextState();
}

class _AppButtonIconTextState extends State<AppButtonIconText> {
  bool isBussy = false;
  @override
  initState() {
    super.initState();
  }

  Future onPressed() async {
    try {
      if (isBussy) return;
      setState(() => isBussy = true);
      await widget.onPressed();
      setState(() => isBussy = false);
    } catch (err) {}
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return RaisedButton(
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(5)),
        //
        padding: EdgeInsets.all(5),
        color: widget.color ?? ThemeService.mainColor,
        onPressed: onPressed,
        child: Container(
          height: widget.height,
          child: Center(
              child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              isBussy
                  ? Transform.scale(
                      scale: 0.5,
                      child: CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation<Color>(
                            ThemeService.textOnMainColor),
                      ))
                  : Transform.scale(scale: 0.8, child: widget.icon),
              widget.isFullRow
                  ? Expanded(
                      child: Text(
                      widget.label,
                      maxLines: 2,
                      softWrap: true,
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.clip,
                      style: TextStyle(color: ThemeService.textOnMainColor),
                    ))
                  : Text(
                      widget.label,
                      maxLines: 2,
                      softWrap: true,
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.clip,
                      style: TextStyle(color: ThemeService.textOnMainColor),
                    )
            ],
          )),
        ));
  }
}

==> tecfy_basic_package-1.0.2.tar.gz: lib/views/components/button_icon_text.dart <==
part of tecfy_basic_package;

class AppButtonIconText extends StatefulWidget {
  final String label;
  final Widget? icon;
  final double? height;
  final Color? color;
  final bool isFullRow;
  final Future Function()? onPressed;
  AppButtonIconText(
      {required this.label,
      this.icon,
      this.onPressed,
      this.color,
      this.height,
      this.isFullRow = false});
  @override
  _AppButtonIconTextState createState() => _AppButtonIconTextState();
}

class _AppButtonIconTextState extends State<AppButtonIconText> {
  bool isBussy = false;
  @override
  initState() {
    super.initState();
  }

  Future onPressed() async {
    try {
      if (isBussy) return;
      setState(() => isBussy = true);
      await widget.onPressed?.call();
      setState(() => isBussy = false);
    } catch (err) {}
  }

  @override
  void dispose() {
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialButton(
        shape: RoundedRectangleBorder(borderRadius: BorderRadius.circular(5)),
        //
        padding: EdgeInsets.all(5),
        color: widget.color ?? ThemeService.mainColor,
        onPressed: onPressed,
        child: Container(
          height: widget.height,
          child: Center(
              child: Row(
            mainAxisAlignment: MainAxisAlignment.center,
            children: <Widget>[
              isBussy
                  ? Transform.scale(
                      scale: 0.5,
                      child: CircularProgressIndicator(
                        valueColor: AlwaysStoppedAnimation<Color>(
                            ThemeService.textOnMainColor),
                      ))
                  : Transform.scale(scale: 0.8, child: widget.icon),
              widget.isFullRow
                  ? Expanded(
                      child: Text(
                      widget.label,
                      maxLines: 2,
                      softWrap: true,
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.clip,
                      style: TextStyle(color: ThemeService.textOnMainColor),
                    ))
                  : Text(
                      widget.label,
                      maxLines: 2,
                      softWrap: true,
                      textAlign: TextAlign.center,
                      overflow: TextOverflow.clip,
                      style: TextStyle(color: ThemeService.textOnMainColor),
                    )
            ],
          )),
        ));
  }
}
